@@ -29,8 +29,12 @@ bundledPrograms = catMaybes
 	, Just "xargs"
 #endif
 	, Just "rsync"
+#ifndef darwin_HOST_OS
+	-- OS X has ssh installed by default.
+	-- (Linux probably, but not guaranteed.)
 	, Just "ssh"
 	, Just "ssh-keygen"
+#endif
 #ifndef mingw32_HOST_OS
 	, Just "sh"
 #endif
@@ -50,8 +54,9 @@ bundledPrograms = catMaybes
 	, Just "gunzip"
 	, Just "tar"
 #endif
-	-- nice and ionice are not included in the bundle; we rely on the
-	-- system's own version, which may better match its kernel
+	-- nice, ionice, and nocache are not included in the bundle;
+	-- we rely on the system's own version, which may better match
+	-- its kernel, and avoid using them if not available.
 	]
   where
 	ifset True s = Just s
